# Media files

These are a collection of media files generated by Daniel Cuevas. These correspond to the media that we use in our
Genotype to Phenotype project. 

Each file has the format:

```
    [Compound, Name, Formula, Charge] 
```

The data is separated by tabs.

By default, the first line is the header line of the file that describes the columns.

## MOPS media

The MOPS media we use is based on a recipe by [Neidhardt et al., 1974](http://www.ncbi.nlm.nih.gov/pubmed/4604283). We 
have two main varieties: MOPS_NoC is the basic MOPS media with no carbon source and ammonia as the nitrogen source. 
MOPS_NoN is the basic MOPS media with Glucose as the carbon source but no nitrogen source.

